@@ -7,9 +7,7 @@
 **      Date Started: Dec 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -83,9 +81,14 @@ PlotFile::addColumn (int iCol, const double* const pdColData)
     return (false);
   }
 
-  for (int iRec = 0; iRec < m_iNumRecords; iRec++)
+  for (int iRec = 0; iRec < m_iNumRecords; iRec++) {
     m_vecCurves[ iRec + (iCol * m_iNumRecords) ] = pdColData [iRec];
-
+#if 0
+    sys_error (ERR_TRACE, "Storing m_vecCurves[%d] = %f",
+               iRec + (iCol * m_iNumRecords),
+               pdColData [iRec]);
+#endif
+  }
   return true;
 }
 
@@ -139,6 +142,7 @@ PlotFile::getMinMax (int iStartingCol, double& dMin, double& dMax) const
     }
   }
 
+  //  sys_error (ERR_TRACE, "dMin=%f, dMax=%f", dMin, dMax);
   return true;
 }
 
