@@ -7,9 +7,7 @@
 **   Date Started:  February 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -57,13 +55,13 @@ private:
   SupervisorThread* m_pMyThread;
   wxWindow* m_pParentFrame;
   BackgroundProcessingDocument* m_pDocument;
-  const std::string m_strProcessTitle;
+  const wxString m_strProcessTitle;
 
   const unsigned int m_iTotalUnits;
   int m_iNumThreads;
   volatile bool m_bDone;
   volatile bool m_bFail;
-  std::string m_strFailMessage;
+  wxString m_strFailMessage;
   volatile bool m_bCancelled;
   volatile int m_iRunning;
   volatile unsigned int m_iUnitsDone;
@@ -88,7 +86,7 @@ public:
     MSG_WORKER_THREAD_FAIL = 7507,   // sent by workers when they fail
   };
 
-  BackgroundSupervisor (SupervisorThread* pMyThread, wxWindow* pParentFrame, BackgroundProcessingDocument* pDocument, const char* const pszProcessTitle,
+  BackgroundSupervisor (SupervisorThread* pMyThread, wxWindow* pParentFrame, BackgroundProcessingDocument* pDocument, wxChar const* pszProcessTitle,
     int iTotalUnits);
 
   BackgroundSupervisor ()
@@ -105,7 +103,7 @@ public:
 
   virtual void onCancel();
 
-  virtual void onWorkerFail(int iThread, std::string strFailMessage);
+  virtual void onWorkerFail(int iThread, const wxString& strFailMessage);
   virtual void onWorkerUnitTick();
   virtual void onWorkerDone(int iThread);
 
@@ -116,7 +114,7 @@ public:
   bool isDone() const {return m_bDone;}
   void setDone() { m_bDone = true; }
   bool fail() const {return m_bFail;}
-  const std::string& getFailMessage() const { return m_strFailMessage; }
+  const wxString& getFailMessage() const { return m_strFailMessage; }
   bool cancelled() const {return m_bCancelled;}
 
   int getNumWorkers() const { return m_iNumThreads; }
