@@ -7,9 +7,7 @@
 **   Date Started:  July 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -38,6 +36,7 @@
 #include "wx/image.h"
 #include "wx/filesys.h"
 #include "wx/fs_zip.h"
+#include "wx/cmdline.h"
 #ifdef __WXMSW__
 #include "wx/msw/helpchm.h"
 #endif
@@ -69,22 +68,15 @@
 #endif
 #endif
 
-static const char* rcsindent = "$Id$";
-
-struct option CTSimApp::ctsimOptions[] =
-{
-  {"help", 0, 0, O_HELP},
-  {"version", 0, 0, O_VERSION},
-  {"print", 0, 0, O_PRINT},
-  {0, 0, 0, 0}
-};
 
 IMPLEMENT_APP(CTSimApp)
 
 CTSimApp::CTSimApp()
-:  m_bAdvancedOptions(false), m_bSetModifyNewDocs(true), m_bVerboseLogging(false), m_bShowStartupTips(true),
-m_iCurrentTip(0), m_bUseBackgroundTasks(false),
-m_docManager(NULL), m_pFrame(NULL), m_pConfig(0), m_pLog(0), m_pLogDoc(0)
+: m_bAdvancedOptions(false), m_bSetModifyNewDocs(true), 
+  m_bVerboseLogging(false), m_bShowStartupTips(true),
+  m_iCurrentTip(0), m_bUseBackgroundTasks(false),
+  m_docManager(NULL), m_pFrame(NULL), m_pConfig(0), m_pLog(0), m_pLogDoc(0),
+  m_bPrintCmdLineImages(false), m_bCmdLineVerboseFlag(false)
 {
   theApp = this;
 }
@@ -97,9 +89,58 @@ m_docManager(NULL), m_pFrame(NULL), m_pConfig(0), m_pLog(0), m_pLogDoc(0)
 #include <sys/resource.h>
 #endif
 
+
+void CTSimApp::OnInitCmdLine(wxCmdLineParser& parser)
+{
+  static const wxCmdLineEntryDesc cmdLineDesc[] = {
+    { wxCMD_LINE_SWITCH, _T("l"), _T("verbose"), _T("verbose logging") },
+    { wxCMD_LINE_SWITCH, _T("v"), _T("version"), _T("print version") },
+    { wxCMD_LINE_SWITCH, _T("p"), _T("print"), _T("print images from command line"),
+      wxCMD_LINE_VAL_NONE,
+      wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_SWITCH, _T("h"), _T("help"), _T("print this help message"),
+      wxCMD_LINE_VAL_NONE,
+      wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_OPTION_HELP },
+    { wxCMD_LINE_PARAM, NULL, NULL, _T("input file"),
+      wxCMD_LINE_VAL_STRING,
+      wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_PARAM_MULTIPLE },
+    { wxCMD_LINE_NONE }
+  };
+
+  parser.SetDesc(cmdLineDesc);
+}
+
+bool CTSimApp::OnCmdLineParsed(wxCmdLineParser& parser)
+{
+  if (wxApp::OnCmdLineParsed(parser) == false)
+    return false;
+
+  if (parser.Found(_T("version"))) {
+#ifdef VERSION
+      std::cout << "Version: " << VERSION << std::endl;
+#elif defined(CTSIMVERSION)
+      std::cout << "Version: " << CTSIMVERSION << std::endl;
+#else
+      std::cout << "Version: " << "Unknown" << std::endl;
+#endif
+      return false;
+  }
+  if (parser.Found(_T("print"))) {
+    m_bPrintCmdLineImages = true;
+  }
+  if (parser.Found(_T("verbose"))) {
+    m_bCmdLineVerboseFlag = true;
+  }
+
+  return true;
+}
+
 bool
 CTSimApp::OnInit()
 {
+  if (! wxApp::OnInit())
+    return false;
+
 #ifdef HAVE_SETPRIORITY
   setpriority (PRIO_PROCESS, 0, 15);  // set to low scheduling priority
 #endif
@@ -107,48 +148,17 @@ CTSimApp::OnInit()
   openConfig();
 
   g_bRunningWXWindows = true;
-  bool bPrintFiles = false;
-  // process options
-  while (1) {
-#ifdef __WXMAC__
-    int c = -1;
-#else
-    int c = getopt_long (argc, argv, "", ctsimOptions, NULL);
-#endif
-    if (c == -1)
-      break;
-
-    switch (c) {
-    case O_VERSION:
-      std::cout << rcsindent << std::endl;
-#ifdef VERSION
-      std::cout << "Version: " << VERSION << std::endl;
-#elif defined(CTSIMVERSION)
-      std::cout << "Version: " << CTSIMVERSION << std::endl;
-#endif
-      exit(0);
-    case O_HELP:
-    case '?':
-      usage (argv[0]);
-      exit (0);
-    case O_PRINT:
-      bPrintFiles = true;
-      break;
-    default:
-      usage (argv[0]);
-      exit (1);
-    }
-  }
-
   m_docManager = new wxDocManager (wxDEFAULT_DOCMAN_FLAGS, true);
 
-  m_pDocTemplImage = new wxDocTemplate (m_docManager, "ImageFile", "*.if", "", "if", "ImageFile", "ImageView", CLASSINFO(ImageFileDocument), CLASSINFO(ImageFileView));
-  m_pDocTemplProjection = new wxDocTemplate (m_docManager, "ProjectionFile", "*.pj", "", "pj", "ProjectionFile", "ProjectionView", CLASSINFO(ProjectionFileDocument), CLASSINFO(ProjectionFileView));
-  m_pDocTemplPhantom = new wxDocTemplate (m_docManager, "PhantomFile", "*.phm", "", "phm", "PhantomFile", "PhantomView", CLASSINFO(PhantomFileDocument), CLASSINFO(PhantomFileView));
-  m_pDocTemplPlot = new wxDocTemplate (m_docManager, "PlotFile", "*.plt", "", "plt", "PlotFile", "PlotView", CLASSINFO(PlotFileDocument), CLASSINFO(PlotFileView));
-  m_pDocTemplText = new wxDocTemplate (m_docManager, "TextFile", "*.txt", "", "txt", "TextFile", "TextView", CLASSINFO(TextFileDocument), CLASSINFO(TextFileView), wxTEMPLATE_INVISIBLE);
+  m_pDocTemplImage = new wxDocTemplate (m_docManager, _T("ImageFile"), _T("*.if"), _T(""), _T("if"), _T("ImageFile"), _T("ImageView"), CLASSINFO(ImageFileDocument), CLASSINFO(ImageFileView));
+  m_pDocTemplProjection = new wxDocTemplate (m_docManager, _T("ProjectionFile"), _T("*.pj"), _T(""), _T("pj"), _T("ProjectionFile"), _T("ProjectionView"), CLASSINFO(ProjectionFileDocument), CLASSINFO(ProjectionFileView));
+  m_pDocTemplPhantom = new wxDocTemplate (m_docManager, _T("PhantomFile"), _T("*.phm"), _T(""), _T("phm"), _T("PhantomFile"), _T("PhantomView"), CLASSINFO(PhantomFileDocument), CLASSINFO(PhantomFileView));
+  m_pDocTemplPlot = new wxDocTemplate (m_docManager, _T("PlotFile"), _T("*.plt"), _T(""), _T("plt"), _T("PlotFile"), _T("PlotView"), CLASSINFO(PlotFileDocument), CLASSINFO(PlotFileView));
+  m_pDocTemplText = new wxDocTemplate (m_docManager, _T("TextFile"), _T("*.txt"), _T(""), _T("txt"), _T("TextFile"), _T("TextView"), CLASSINFO(TextFileDocument), CLASSINFO(TextFileView), wxTEMPLATE_INVISIBLE);
 #if wxUSE_GLCANVAS
-  m_pDocTemplGraph3d = new wxDocTemplate (m_docManager, "Graph3dFile", "*.g3d", "", "g3d", "Graph3dFile", "Graph3dView", CLASSINFO(Graph3dFileDocument), CLASSINFO(Graph3dFileView), wxTEMPLATE_INVISIBLE);
+  m_pDocTemplGraph3d = new wxDocTemplate (m_docManager, _T("Graph3dFile"), _T("*.g3d"), _T(""), _T("g3d"),
+                                          _T("Graph3dFile"), _T("Graph3dView"), CLASSINFO(Graph3dFileDocument), 
+                                          CLASSINFO(Graph3dFileView), wxTEMPLATE_INVISIBLE);
 #endif
 
 #if wxUSE_GIF
@@ -163,13 +173,13 @@ CTSimApp::OnInit()
   int xDisplay, yDisplay;
   ::wxDisplaySize (&xDisplay, &yDisplay);
 
-  m_pFrame = new MainFrame(m_docManager, (wxFrame *) NULL, -1, "CTSim", wxPoint(0, 0),
 #ifdef CTSIM_MDI
-    wxSize(nearest<int>(xDisplay * .75), nearest<int>(yDisplay * .75)),
+  wxSize frameSize(nearest<int>(xDisplay * .75), nearest<int>(yDisplay * .75));
 #else
-    wxSize(nearest<int>(xDisplay * .6), nearest<int>(yDisplay * .4)),
+  wxSize frameSize(nearest<int>(xDisplay * .6), nearest<int>(yDisplay * .4));
 #endif
-    wxDEFAULT_FRAME_STYLE);
+
+  m_pFrame = new MainFrame(m_docManager, (wxFrame *) NULL, -1, _T("CTSim"), wxPoint(0, 0), frameSize, wxDEFAULT_FRAME_STYLE);
 
   setIconForFrame (m_pFrame);
   m_pFrame->Centre(wxBOTH);
@@ -183,9 +193,9 @@ CTSimApp::OnInit()
   m_pLogDoc = newTextDoc();
   if (m_pLogDoc) {
     m_pLog = m_pLogDoc->getTextCtrl();
-    m_pLogDoc->SetDocumentName("Log.txt");
-    m_pLogDoc->SetFilename("Log.txt");
-    m_pLogDoc->getView()->getFrame()->SetTitle("Log");
+    m_pLogDoc->SetDocumentName(_T("Log.txt"));
+    m_pLogDoc->SetFilename(_T("Log.txt"));
+    m_pLogDoc->getView()->getFrame()->SetTitle(_T("Log"));
     int xSize, ySize;
     m_pFrame->GetClientSize(&xSize, &ySize);
     int yLogSize = ySize / 4;
@@ -193,29 +203,29 @@ CTSimApp::OnInit()
     m_pLogDoc->getView()->getFrame()->Show (true);
   } else
 #else
-    m_pLog = new wxTextCtrl (m_pFrame, -1, "Log Window\n", wxPoint(0, 0), wxSize(0,0), wxTE_MULTILINE | wxTE_READONLY);
+    m_pLog = new wxTextCtrl (m_pFrame, -1, _T("Log Window\n"), wxPoint(0, 0), frameSize, wxTE_MULTILINE | wxTE_READONLY);
 #endif
   wxLog::SetActiveTarget (new wxLogTextCtrl(m_pLog));
 
   wxString helpDir;
-  if (! m_pConfig->Read("HelpDir", &helpDir))
+  if (! m_pConfig->Read(_T("HelpDir"), &helpDir))
     helpDir = ::wxGetCwd();
 #ifdef CTSIM_WINHELP
-  if (! m_pFrame->getWinHelpController().Initialize(helpDir + "/ctsim"))
-    *m_pLog << "Cannot initialize the Windows Help system" << "\n";
+  if (! m_pFrame->getWinHelpController().Initialize(helpDir + _T("/ctsim")))
+    *m_pLog << _T("Cannot initialize the Windows Help system") << _T("\n");
 #else
 #ifdef DATADIR
-  wxString docDir (DATADIR);
+  wxString docDir (DATADIR, *wxConvCurrent);
 #else
   wxString docDir (::wxGetCwd());
 #endif
-  wxString docFile = docDir + "ctsim.htb";
+  wxString docFile = docDir + _T("ctsim.htb");
   if (! m_pFrame->getHtmlHelpController().AddBook(docFile) &&
-    ! m_pFrame->getHtmlHelpController().AddBook("/usr/share/ctsim/ctsim.htb") &&
-        ! m_pFrame->getHtmlHelpController().AddBook("/tmp/ctsim.htb"))
-        *m_pLog << "Cannot initialize the HTML Help system" << "\n";
+      ! m_pFrame->getHtmlHelpController().AddBook(_T("/usr/share/ctsim/ctsim.htb")) &&
+      ! m_pFrame->getHtmlHelpController().AddBook(_T("/tmp/ctsim.htb")))
+    *m_pLog << _T("Cannot initialize the HTML Help system") << _T("\n");
   else {
-    if (::wxDirExists ("/tmp"))
+    if (::wxDirExists (_T("/tmp")))
       m_pFrame->getHtmlHelpController().SetTempDir(_T("/tmp"));
     m_pFrame->getHtmlHelpController().UseConfig (m_pConfig);
   }
@@ -224,7 +234,7 @@ CTSimApp::OnInit()
   for (int i = optind + 1; i <= argc; i++) {
     wxString filename = argv [i - 1];
     wxDocument* pNewDoc = m_docManager->CreateDocument (filename, wxDOC_SILENT);
-    if (bPrintFiles) {
+    if (m_bPrintCmdLineImages) {
       wxView* pNewView = pNewDoc->GetFirstView();
       wxPrintout *printout = pNewView->OnCreatePrintout();
       if (printout) {
@@ -237,7 +247,7 @@ CTSimApp::OnInit()
       m_docManager->OnFileClose (nullEvent);
     }
   }
-  if (bPrintFiles) {
+  if (m_bPrintCmdLineImages) {
     wxCommandEvent closeEvent;
     closeEvent.SetInt (MAINMENU_FILE_EXIT);
     m_pFrame->AddPendingEvent(closeEvent);
@@ -297,58 +307,46 @@ void
 CTSimApp::openConfig()
 {
 #ifdef MSVC
-  m_pConfig = new wxConfig("ctsim", "Kevin Rosenberg", "", "", wxCONFIG_USE_LOCAL_FILE);
+  m_pConfig = new wxConfig(_T("ctsim"), _T("Kevin Rosenberg"), _T(""), _T(""), wxCONFIG_USE_LOCAL_FILE);
 #else
-  m_pConfig = new wxConfig("ctsim", "Kevin Rosenberg", ".ctsim", "", wxCONFIG_USE_LOCAL_FILE);
+  m_pConfig = new wxConfig(_T("ctsim"), _T("Kevin Rosenberg"), _T(".ctsim"), _T(""), wxCONFIG_USE_LOCAL_FILE);
 #endif
 
   wxConfigBase::Set(m_pConfig);
-  m_pConfig->Read ("AdvancedOptions", &m_bAdvancedOptions);
-  m_pConfig->Read ("SetModifyNewDocs", &m_bSetModifyNewDocs);
-  m_pConfig->Read ("VerboseLogging", &m_bVerboseLogging);
-  m_pConfig->Read ("StartupTips", &m_bShowStartupTips);
-  m_pConfig->Read ("CurrentTip", &m_iCurrentTip);
-  m_pConfig->Read ("UseBackgroundTasks", &m_bUseBackgroundTasks);
+  m_pConfig->Read (_T("AdvancedOptions"), &m_bAdvancedOptions);
+  m_pConfig->Read (_T("SetModifyNewDocs"), &m_bSetModifyNewDocs);
+  m_pConfig->Read (_T("VerboseLogging"), &m_bVerboseLogging);
+  m_pConfig->Read (_T("StartupTips"), &m_bShowStartupTips);
+  m_pConfig->Read (_T("CurrentTip"), &m_iCurrentTip);
+  m_pConfig->Read (_T("UseBackgroundTasks"), &m_bUseBackgroundTasks);
 #ifdef HAVE_FFTW
   wxString strFftwWisdom;
-  m_pConfig->Read ("FftwWisdom", strFftwWisdom);
+  m_pConfig->Read (_T("FftwWisdom"), strFftwWisdom);
   if (strFftwWisdom.size() > 0)
-    fftw_import_wisdom_from_string (strFftwWisdom.c_str());
+    fftw_import_wisdom_from_string (strFftwWisdom.mb_str(wxConvUTF8));
 #endif
 }
 
 void
 CTSimApp::closeConfig()
 {
-  m_pConfig->Write ("AdvancedOptions", m_bAdvancedOptions);
-  m_pConfig->Write ("SetModifyNewDocs", m_bSetModifyNewDocs);
-  m_pConfig->Write ("VerboseLogging", m_bVerboseLogging);
-  m_pConfig->Write ("StartupTips", m_bShowStartupTips);
-  m_pConfig->Write ("CurrentTip", m_iCurrentTip);
-  m_pConfig->Write ("UseBackgroundTasks", m_bUseBackgroundTasks);
+  m_pConfig->Write (_T("AdvancedOptions"), m_bAdvancedOptions);
+  m_pConfig->Write (_T("SetModifyNewDocs"), m_bSetModifyNewDocs);
+  m_pConfig->Write (_T("VerboseLogging"), m_bVerboseLogging);
+  m_pConfig->Write (_T("StartupTips"), m_bShowStartupTips);
+  m_pConfig->Write (_T("CurrentTip"), m_iCurrentTip);
+  m_pConfig->Write (_T("UseBackgroundTasks"), m_bUseBackgroundTasks);
 #ifdef HAVE_FFTW
   const char* const pszWisdom = fftw_export_wisdom_to_string();
-  wxString strFftwWisdom (pszWisdom);
+  wxString strFftwWisdom (pszWisdom, *wxConvCurrent);
   fftw_free ((void*) pszWisdom);
-  m_pConfig->Write ("FftwWisdom", strFftwWisdom);
+  m_pConfig->Write (_T("FftwWisdom"), strFftwWisdom);
 #endif
 
   delete m_pConfig;
 }
 
 
-wxString
-CTSimApp::getUntitledFilename()
-{
-  static int untitledNumber = 1;
-
-  wxString filename ("Untitled");
-  filename << untitledNumber++;
-
-  return (filename);
-}
-
-
 // Top-level window for CTSim
 
 #if CTSIM_MDI
@@ -418,10 +416,10 @@ END_EVENT_TABLE()
 
 #if CTSIM_MDI
 MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, const long type)
-: wxDocMDIParentFrame(manager, NULL, id, title, pos, size, type, "MainFrame")
+: wxDocMDIParentFrame(manager, NULL, id, title, pos, size, type, _T("MainFrame"))
 #else
 MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, const long type)
-: wxDocParentFrame(manager, frame, id, title, pos, size, type, "MainFrame")
+: wxDocParentFrame(manager, frame, id, title, pos, size, type, _T("MainFrame"))
 #endif
 {
   m_bShuttingDown = false;
@@ -429,14 +427,14 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
   //// Make a menubar
   wxMenu *file_menu = new wxMenu;
 
-  file_menu->Append(MAINMENU_FILE_CREATE_PHANTOM, "Cr&eate Phantom...\tCtrl-P");
-  file_menu->Append(MAINMENU_FILE_CREATE_FILTER, "Create &Filter...\tCtrl-F");
-  file_menu->Append(wxID_OPEN, "&Open...\tCtrl-O");
+  file_menu->Append(MAINMENU_FILE_CREATE_PHANTOM, _T("Cr&eate Phantom...\tCtrl-P"));
+  file_menu->Append(MAINMENU_FILE_CREATE_FILTER, _T("Create &Filter...\tCtrl-F"));
+  file_menu->Append(wxID_OPEN, _T("&Open...\tCtrl-O"));
 
   file_menu->AppendSeparator();
-  file_menu->Append (MAINMENU_IMPORT, "&Import...\tCtrl-M");
-  file_menu->Append (MAINMENU_FILE_PREFERENCES, "Prefere&nces...");
-  file_menu->Append(MAINMENU_FILE_EXIT, "E&xit");
+  file_menu->Append (MAINMENU_IMPORT, _T("&Import...\tCtrl-M"));
+  file_menu->Append (MAINMENU_FILE_PREFERENCES, _T("Prefere&nces..."));
+  file_menu->Append(MAINMENU_FILE_EXIT, _T("E&xit"));
 
   //  history of files visited
   theApp->getDocManager()->FileHistoryAddFilesToMenu(file_menu);
@@ -448,21 +446,21 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
 #endif
 
   wxMenu* help_menu = new wxMenu;
-  help_menu->Append (MAINMENU_HELP_CONTENTS, "&Contents\tF1");
-  help_menu->Append (MAINMENU_HELP_TIPS, "&Tips");
-  help_menu->Append (IDH_QUICKSTART, "&Quick Start");
+  help_menu->Append (MAINMENU_HELP_CONTENTS, _T("&Contents\tF1"));
+  help_menu->Append (MAINMENU_HELP_TIPS, _T("&Tips"));
+  help_menu->Append (IDH_QUICKSTART, _T("&Quick Start"));
 #if defined(CTSIM_WINHELP) && (defined(DEBUG) || defined(_DEBUG))
-  help_menu->Append (MAINMENU_HELP_SECONDARY, "&Secondary Help");
+  help_menu->Append (MAINMENU_HELP_SECONDARY, _T("&Secondary Help"));
 #endif
-  help_menu->Append (MAINMENU_HELP_ABOUT, "&About");
+  help_menu->Append (MAINMENU_HELP_ABOUT, _T("&About"));
 
   wxMenuBar* menu_bar = new wxMenuBar;
 
-  menu_bar->Append(file_menu, "&File");
+  menu_bar->Append(file_menu, _T("&File"));
 #ifndef CTSIM_MDI
-  menu_bar->Append(m_pWindowMenu, "&Window");
+  menu_bar->Append(m_pWindowMenu, _T("&Window"));
 #endif
-  menu_bar->Append(help_menu, "&Help");
+  menu_bar->Append(help_menu, _T("&Help"));
 
   SetMenuBar(menu_bar);
 
@@ -470,7 +468,7 @@ MainFrame::MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const
 #ifndef CTSIM_MDI
   int i;
   for (i = 0; i < MAX_WINDOW_MENUITEMS; i++) {
-    m_apWindowMenuItems[i] = new wxMenuItem (m_pWindowMenu, MAINMENU_WINDOW_BASE+i, wxString("[EMPTY]"));
+    m_apWindowMenuItems[i] = new wxMenuItem (m_pWindowMenu, MAINMENU_WINDOW_BASE+i, _T("[EMPTY]"));
     m_pWindowMenu->Append (m_apWindowMenuItems[i]);
     m_pWindowMenu->Enable (MAINMENU_WINDOW_BASE+i, false);
   }
@@ -552,11 +550,11 @@ MainFrame::OnCreatePhantom(wxCommandEvent& event)
   DialogGetPhantom dialogPhantom (this, m_iDefaultPhantomID);
   int dialogReturn = dialogPhantom.ShowModal();
   if (dialogReturn == wxID_OK) {
-    wxString selection (dialogPhantom.getPhantom());
+    wxString selection (dialogPhantom.getPhantom(), *wxConvCurrent);
     if (theApp->getVerboseLogging())
-      *theApp->getLog() << "Selected phantom " << selection.c_str() << "\n";
-    wxString filename = selection + ".phm";
-    m_iDefaultPhantomID = Phantom::convertNameToPhantomID (selection.c_str());
+      *theApp->getLog() << _T("Selected phantom ") << selection.c_str() << _T("\n");
+    wxString filename = selection + _T(".phm");
+    m_iDefaultPhantomID = Phantom::convertNameToPhantomID (selection.mb_str(wxConvUTF8));
     theApp->getDocManager()->CreateDocument (filename, wxDOC_SILENT);
   }
 
@@ -568,23 +566,25 @@ MainFrame::OnCreateFilter (wxCommandEvent& WXUNUSED(event))
   DialogGetFilterParameters dialogFilter (this, m_iDefaultFilterXSize, m_iDefaultFilterYSize, m_iDefaultFilterID, m_dDefaultFilterParam, m_dDefaultFilterBandwidth, m_iDefaultFilterDomainID, m_dDefaultFilterInputScale, m_dDefaultFilterOutputScale);
   int dialogReturn = dialogFilter.ShowModal();
   if (dialogReturn == wxID_OK) {
-    wxString strFilter (dialogFilter.getFilterName());
-    wxString strDomain (dialogFilter.getDomainName());
-    m_iDefaultFilterID = SignalFilter::convertFilterNameToID (strFilter.c_str());
-    m_iDefaultFilterDomainID = SignalFilter::convertDomainNameToID (strDomain.c_str());
+    wxString strFilter (dialogFilter.getFilterName(), *wxConvCurrent);
+    wxString strDomain (dialogFilter.getDomainName(), *wxConvCurrent);
+    m_iDefaultFilterID = SignalFilter::convertFilterNameToID (strFilter.mb_str(wxConvUTF8));
+    m_iDefaultFilterDomainID = SignalFilter::convertDomainNameToID (strDomain.mb_str(wxConvUTF8));
     m_iDefaultFilterXSize = dialogFilter.getXSize();
     m_iDefaultFilterYSize = dialogFilter.getYSize();
     m_dDefaultFilterBandwidth = dialogFilter.getBandwidth();
     m_dDefaultFilterParam= dialogFilter.getFilterParam();
     m_dDefaultFilterInputScale = dialogFilter.getInputScale();
     m_dDefaultFilterOutputScale = dialogFilter.getOutputScale();
-    std::ostringstream os;
-    os << "Generate Filter=" << strFilter.c_str()
-      << ", size=(" << static_cast<int>(m_iDefaultFilterXSize) << "," << static_cast<int>(m_iDefaultFilterYSize)
-      << "), domain=" << strDomain.c_str() << ", filterParam=" << m_dDefaultFilterParam << ", bandwidth=" << m_dDefaultFilterBandwidth
-      << ", inputScale=" << m_dDefaultFilterInputScale << ", outputScale=" << m_dDefaultFilterOutputScale;
-    *theApp->getLog() << os.str().c_str() << "\n";
-    wxString filename = "untitled.if";
+    wxString os;
+    os << _T("Generate Filter=") << strFilter
+       << _T(", size=(") << static_cast<int>(m_iDefaultFilterXSize) << _T(",")
+       << static_cast<int>(m_iDefaultFilterYSize)
+       << _T("), domain=") << strDomain.c_str() << _T(", filterParam=")
+       << m_dDefaultFilterParam << _T(", bandwidth=") <<
+      m_dDefaultFilterBandwidth
+       << _T(", inputScale=") << m_dDefaultFilterInputScale << _T(", outputScale=") << m_dDefaultFilterOutputScale;
+    *theApp->getLog() << os << _T("\n");
     ImageFileDocument* pFilterDoc = theApp->newImageDoc();
     pFilterDoc->setBadFileOpen();
     if (! pFilterDoc) {
@@ -593,8 +593,8 @@ MainFrame::OnCreateFilter (wxCommandEvent& WXUNUSED(event))
     }
     ImageFile& rIF = pFilterDoc->getImageFile();
     rIF.setArraySize (m_iDefaultFilterXSize, m_iDefaultFilterYSize);
-    rIF.filterResponse (strDomain.c_str(), m_dDefaultFilterBandwidth, strFilter.c_str(), m_dDefaultFilterParam, m_dDefaultFilterInputScale, m_dDefaultFilterOutputScale);
-    rIF.labelAdd (os.str().c_str());
+    rIF.filterResponse (strDomain.mb_str(wxConvUTF8), m_dDefaultFilterBandwidth, strFilter.mb_str(wxConvUTF8), m_dDefaultFilterParam, m_dDefaultFilterInputScale, m_dDefaultFilterOutputScale);
+    rIF.labelAdd (os.mb_str(wxConvUTF8));
     if (theApp->getAskDeleteNewDocs())
       pFilterDoc->Modify (true);
     pFilterDoc->UpdateAllViews();
@@ -693,7 +693,7 @@ MainFrame::showHelp (int commandID)
 #ifdef CTSIM_WINHELP
     m_winHelp.DisplayContents ();
 #else
-    m_htmlHelp.Display ("Contents");
+    m_htmlHelp.Display (_T("Contents"));
 #endif
     break;
 
@@ -724,7 +724,7 @@ MainFrame::OnUpdateUI (wxUpdateUIEvent& rEvent)
     wxDocument* pDoc = static_cast<wxDocument*>(pNode->GetData());
     wxString strFilename = pDoc->GetFilename();
     if (iPos < 10) {
-      strFilename += "\tCtrl-";
+      strFilename += _T("\tCtrl-");
       strFilename += static_cast<char>('0' + iPos);
     }
     static_cast<wxMenuItemBase*>(m_apWindowMenuItems[iPos])->SetName (strFilename);
@@ -735,7 +735,7 @@ MainFrame::OnUpdateUI (wxUpdateUIEvent& rEvent)
   }
   for (int i = iPos; i < MAX_WINDOW_MENUITEMS; i++) {
     m_pWindowMenu->Enable (MAINMENU_WINDOW_BASE+i, false);
-    static_cast<wxMenuItemBase*>(m_apWindowMenuItems[i])->SetName (wxString("[EMPTY]"));
+    static_cast<wxMenuItemBase*>(m_apWindowMenuItems[i])->SetName (_T("[EMPTY]"));
     m_apWindowMenuData[i] = NULL;
   }
 #endif
@@ -830,7 +830,7 @@ public:
     const wxSize& size = wxDefaultSize,
     long style = wxSTATIC_BORDER,
     const wxValidator& validator = wxDefaultValidator,
-    const wxString& name = "BitmapCtrl");
+                 const wxString& name = _T("BitmapCtrl"));
 
 
   virtual ~BitmapControl();
@@ -891,14 +891,14 @@ public:
 };
 
 BitmapDialog::BitmapDialog (wxBitmap* pBitmap, char const* pszTitle)
-: wxDialog(theApp->getMainFrame(), -1, wxString(pszTitle), wxDefaultPosition, wxDefaultSize, wxDIALOG_MODAL | wxDEFAULT_DIALOG_STYLE)
+  : wxDialog(theApp->getMainFrame(), -1, wxString(pszTitle,*wxConvCurrent), wxDefaultPosition, wxDefaultSize, wxDIALOG_MODAL | wxDEFAULT_DIALOG_STYLE)
 {
   wxBoxSizer* pTopSizer = new wxBoxSizer (wxVERTICAL);
 
   pTopSizer->Add (new BitmapControl (pBitmap, this), 0, wxALIGN_CENTER | wxALL, 5);
 
   wxBoxSizer* pButtonSizer = new wxBoxSizer (wxHORIZONTAL);
-  wxButton* pButtonOk = new wxButton (this, wxID_OK, "Ok");
+  wxButton* pButtonOk = new wxButton (this, wxID_OK, _T("Ok"));
   pButtonSizer->Add (pButtonOk, 0, wxEXPAND | wxALL, 10);
 
   pTopSizer->Add (pButtonSizer, 0, wxALIGN_CENTER);
@@ -916,7 +916,7 @@ BitmapDialog::~BitmapDialog()
 void
 MainFrame::OnPreferences (wxCommandEvent& WXUNUSED(event) )
 {
-  DialogPreferences dlg (this, "CTSim Preferences", theApp->getAdvancedOptions(),
+  DialogPreferences dlg (this, _T("CTSim Preferences"), theApp->getAdvancedOptions(),
     theApp->getAskDeleteNewDocs(), theApp->getVerboseLogging(), theApp->getStartupTips(),
     theApp->getUseBackgroundTasks());
   if (dlg.ShowModal() == wxID_OK) {
@@ -935,37 +935,38 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
   if (dialogImport.ShowModal() != wxID_OK)
     return;
 
-  wxString strFormatName (dialogImport.getFormatName ());
-  m_iDefaultImportFormat = ImageFile::convertImportFormatNameToID (strFormatName.c_str());
+  wxString strFormatName (dialogImport.getFormatName (), *wxConvCurrent);
+  m_iDefaultImportFormat = ImageFile::convertImportFormatNameToID (strFormatName.mb_str(wxConvUTF8));
 
   wxString strExt;
   wxString strWildcard;
   if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PPM) {
-    strExt = ".ppm";
-    strWildcard = "PPM Files (*.ppm)|*.ppm|PGM Files (*.pgm)|*.pgm";
+    strExt = _T(".ppm");
+    strWildcard = _T("PPM Files (*.ppm)|*.ppm|PGM Files (*.pgm)|*.pgm");
   }
 #ifdef HAVE_PNG
   else if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PNG) {
-    strExt = ".png";
-    strWildcard = "PNG Files (*.png)|*.png";
+    strExt = _T(".png");
+    strWildcard = _T("PNG Files (*.png)|*.png");
   }
 #endif
 #ifdef HAVE_CTN_DICOM
   else if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_DICOM) {
-    strExt = "*.*";
-    strWildcard = "Dicom Files (*.*)|*.*";
+    strExt = _T("*.*");
+    strWildcard = _T("Dicom Files (*.*)|*.*");
   }
 #endif
   else {
     return;
   }
 
-  wxString strFilename = wxFileSelector (wxString("Import Filename"), wxString(""),
-    wxString(""), strExt, strWildcard, wxHIDE_READONLY | wxOPEN);
+  wxString strFilename = wxFileSelector (wxString(wxConvUTF8.cMB2WX("Import Filename")), wxString(wxConvUTF8.cMB2WX("")),
+                                         wxString(wxConvUTF8.cMB2WX("")), strExt, strWildcard, wxOPEN);
+
   if (! strFilename.IsEmpty()) {
     if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PPM || m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_PNG) {
       ImageFile* pIF = new ImageFile;
-      if (pIF->importImage (strFormatName.c_str(), strFilename.c_str())) {
+      if (pIF->importImage (strFormatName.mb_str(wxConvUTF8), strFilename.mb_str(wxConvUTF8))) {
         ImageFileDocument* pIFDoc = theApp->newImageDoc();
         pIFDoc->setImageFile(pIF);
         pIFDoc->getView()->getFrame()->Show(true);
@@ -982,9 +983,9 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
     }
 #ifdef HAVE_CTN_DICOM
     else if (m_iDefaultImportFormat == ImageFile::IMPORT_FORMAT_DICOM) {
-      DicomImporter dicomImport (strFilename.c_str());
+      DicomImporter dicomImport (strFilename.mb_str(wxConvUTF8));
       if (dicomImport.fail()) {
-        ::wxMessageBox (dicomImport.failMessage().c_str(), "Import Error");
+        ::wxMessageBox (wxConvUTF8.cMB2WX(dicomImport.failMessage().c_str()), _T("Import Error"));
       } else if (dicomImport.testImage()) {
         ImageFileDocument* pIFDoc = theApp->newImageDoc();
         ImageFile* pIF = dicomImport.getImageFile();
@@ -1011,7 +1012,7 @@ MainFrame::OnImport (wxCommandEvent& WXUNUSED(event) )
         pProjDoc->getView()->setInitialClientSize();
         pProjDoc->Activate();
       } else
-        ::wxMessageBox ("Unrecognized DICOM file contents", "Import Error");
+        ::wxMessageBox (_T("Unrecognized DICOM file contents"), _T("Import Error"));
     }
 #endif
     else
@@ -1024,66 +1025,78 @@ void
 MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event) )
 {
   wxString strOSDesc = ::wxGetOsDescription();
-  *theApp->getLog() << "Operating System: " << strOSDesc;
-  *theApp->getLog() << ", wxWindows: " << wxVERSION_STRING;
-#ifdef __TIMESTAMP__
-  *theApp->getLog() << ", Build Date: " << __TIMESTAMP__;
+  *theApp->getLog() << _T("Operating System: ") << strOSDesc;
+  *theApp->getLog() << _T(", wxWindows: ") << wxVERSION_STRING;
+#ifdef _TIMESTAMP__
+  *theApp->getLog() << _T(", Build Date: ") << wxConvUTF8.cMB2WX(_TIMESTAMP__);
 #endif
 #if defined(DEBUG)
-  *theApp->getLog() << ", Debug version";
+  *theApp->getLog() << _T(", Debug version");
 #else
-  *theApp->getLog() << ", Release version";
+  *theApp->getLog() << _T(", Release version");
 #endif
 #ifdef VERSION
-    *theApp->getLog() << " " <<  VERSION;
+  *theApp->getLog() << _T(" ") <<  wxConvUTF8.cMB2WX(VERSION);
 #elif defined(CTSIMVERSION)
-    *theApp->getLog() << " " <<  CTSIMVERSION;
+  *theApp->getLog() << _T(" ") <<  _T(CTSIMVERSION);
 #endif
-  *theApp->getLog() << "\n";
+    *theApp->getLog() << _T("\n");
 
   wxBitmap bmp (splash);
   if (bmp.Ok()) {
     BitmapDialog dlg (&bmp, "About CTSim");
     dlg.ShowModal();
   } else {
-    wxString msg = "CTSim\nThe Open Source Computed Tomography Simulator\n";
+    wxString msg = _T("CTSim\nThe Open Source Computed Tomography Simulator\n");
 #ifdef VERSION
-    msg << "Version: " <<  VERSION << "\n\n";
+    msg << _T("Version: ") <<  wxConvUTF8.cMB2WX(VERSION) << _T("\n\n");
 #elif defined(CTSIMVERSION)
-    msg << "Version: " <<  CTSIMVERSION << "\n\n";
+    msg << _T("Version: ") <<  wxConvUTF8.cMB2WX(CTSIMVERSION) << _T("\n\n");
 #endif
-    msg += "Author: Kevin Rosenberg <kevin@rosenberg.net>\nUsage: ctsim [files-to-open..] [--help]";
+    msg += _T("Author: Kevin Rosenberg <kevin@rosenberg.net>\nUsage: ctsim [files-to-open..] [--help]");
 
-    wxMessageBox(msg, "About CTSim", wxOK | wxICON_INFORMATION, this);
-    *theApp->getLog() << msg << "\n";
+    wxMessageBox(msg, _T("About CTSim"), wxOK | wxICON_INFORMATION, this);
+    *theApp->getLog() << msg << wxConvUTF8.cMB2WX("\n");
   }
 }
 
 
 // Create new documents
 
+wxDocument* 
+CTSimApp::newDocumentHelper (wxDocTemplate* tmpl) {
+  wxDocument* newDoc = tmpl->CreateDocument (_T(""));
+  if (newDoc) {
+    newDoc->SetDocumentTemplate (tmpl);
+    newDoc->OnNewDocument();
+    wxString fname = newDoc->GetFilename();
+    fname += _T(".");
+    fname += tmpl->GetDefaultExtension();
+    newDoc->SetDocumentName(fname);
+    newDoc->SetTitle(fname);
+    newDoc->SetFilename(fname, true);
+  }
+
+  return newDoc;
+}
+
 ProjectionFileDocument*
 CTSimApp::newProjectionDoc()
 {
-  ProjectionFileDocument* newDoc = dynamic_cast<ProjectionFileDocument*>(m_pDocTemplProjection->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplProjection->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplProjection);
-    newDoc->OnNewDocument();
-  }
-
+  ProjectionFileDocument* newDoc = dynamic_cast<ProjectionFileDocument*>
+    (newDocumentHelper(m_pDocTemplProjection));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
   return newDoc;
 }
 
 ImageFileDocument*
 CTSimApp::newImageDoc()
 {
-  ImageFileDocument* newDoc = dynamic_cast<ImageFileDocument*>(m_pDocTemplImage->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplImage->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplImage);
-    newDoc->OnNewDocument();
-  }
+  ImageFileDocument* newDoc = dynamic_cast<ImageFileDocument*>
+    (newDocumentHelper(m_pDocTemplImage));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
 
   return newDoc;
 }
@@ -1091,12 +1104,10 @@ CTSimApp::newImageDoc()
 PlotFileDocument*
 CTSimApp::newPlotDoc()
 {
-  PlotFileDocument* newDoc = dynamic_cast<PlotFileDocument*>(m_pDocTemplPlot->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplPlot->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplPlot);
-    newDoc->OnNewDocument();
-  }
+  PlotFileDocument* newDoc = dynamic_cast<PlotFileDocument*>
+    (newDocumentHelper(m_pDocTemplPlot));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
 
   return newDoc;
 }
@@ -1105,15 +1116,10 @@ CTSimApp::newPlotDoc()
 TextFileDocument*
 CTSimApp::newTextDoc()
 {
-  wxString strFilename (getUntitledFilename());
-  strFilename += ".txt";
-
-  TextFileDocument* newDoc = dynamic_cast<TextFileDocument*>(m_pDocTemplText->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplText->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplText);
-    newDoc->OnNewDocument();
-  }
+  TextFileDocument* newDoc = dynamic_cast<TextFileDocument*>
+    (newDocumentHelper(m_pDocTemplText));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
 
   return newDoc;
 }
@@ -1122,12 +1128,10 @@ CTSimApp::newTextDoc()
 PhantomFileDocument*
 CTSimApp::newPhantomDoc()
 {
-  PhantomFileDocument* newDoc = dynamic_cast<PhantomFileDocument*>(m_pDocTemplPhantom->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplPhantom->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplPhantom);
-    newDoc->OnNewDocument();
-  }
+  PhantomFileDocument* newDoc = dynamic_cast<PhantomFileDocument*>
+    (newDocumentHelper(m_pDocTemplPhantom));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
 
   return newDoc;
 }
@@ -1137,13 +1141,12 @@ CTSimApp::newPhantomDoc()
 Graph3dFileDocument*
 CTSimApp::newGraph3dDoc()
 {
-  Graph3dFileDocument* newDoc = dynamic_cast<Graph3dFileDocument*>(m_pDocTemplGraph3d->CreateDocument (""));
-  if (newDoc) {
-    newDoc->SetDocumentName (m_pDocTemplGraph3d->GetDocumentName());
-    newDoc->SetDocumentTemplate (m_pDocTemplGraph3d);
-    newDoc->OnNewDocument();
-  }
+  Graph3dFileDocument* newDoc = dynamic_cast<Graph3dFileDocument*>
+    (newDocumentHelper(m_pDocTemplGraph3d));
+  if (newDoc)
+    newDoc->getView()->getFrame()->SetTitle(newDoc->GetDocumentName());
 
   return newDoc;
 }
+
 #endif
