@@ -7,9 +7,7 @@
 **   Date Started:  July 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -44,7 +42,7 @@ class CTSimHelpButton : public wxButton
 {
 public:
   CTSimHelpButton (wxWindow* parent, int id)
-    : wxButton (parent, id, "Help")
+    : wxButton (parent, id, _T("Help"))
   {}
 };
 
@@ -57,7 +55,14 @@ public:
 class StringValueAndTitleListBox : public wxListBox
 {
  public:
-  StringValueAndTitleListBox (wxDialog* pParent, int nChoices, const char* const aszTitle[], const char* const aszValue[]);
+  StringValueAndTitleListBox (wxDialog* pParent, int nChoices, wxChar const* const* asTitle,
+                              char const* const aszValue[]);
+#if 0
+  StringValueAndTitleListBox (wxDialog* pParent, int nChoices, wxChar const* title,
+                              char const* const* aszTitle, char const* const* aszValue);
+#endif
+  StringValueAndTitleListBox (wxDialog* pParent, int nChoices, wxChar const* title,
+                              wxChar const* const* asTitle, char const* const* aszValue);
 
     const char* getSelectionStringValue () const;
 
@@ -69,7 +74,7 @@ class StringValueAndTitleListBox : public wxListBox
 class StringValueAndTitleRadioBox : public wxRadioBox
 {
  public:
-  StringValueAndTitleRadioBox (wxDialog* pParent, const wxString& strTitle, int nChoices, const char* const aszTitle[], const char* const aszValue[]);
+  StringValueAndTitleRadioBox (wxDialog* pParent, wxChar const* strTitle, int nChoices, const char* const aszTitle[], const char* const aszValue[]);
 
   const char* getSelectionStringValue () const;
 
@@ -108,7 +113,7 @@ class ImageFileDocument;
 class DialogGetComparisonImage : public wxDialog
 {
  public:
-   DialogGetComparisonImage (wxWindow* pParent, const char* const pszTitle, const std::vector<ImageFileDocument*>& rVecIF, bool bShowMakeDifference);
+   DialogGetComparisonImage (wxWindow* pParent, wxChar const * pwszTitle, const std::vector<ImageFileDocument*>& rVecIF, bool bShowMakeDifference);
     virtual ~DialogGetComparisonImage () {}
 
     ImageFileDocument* getImageFileDocument ();
@@ -125,7 +130,7 @@ class DialogGetComparisonImage : public wxDialog
 class DialogPreferences : public wxDialog
 {
  public:
-    DialogPreferences (wxWindow* pParent, const char* const pszTitle, bool bAdvanced, bool bAskNewDocs,
+  DialogPreferences (wxWindow* pParent, wxChar const* pszTitle, bool bAdvanced, bool bAskNewDocs,
       bool bVerboseLogging, bool bStartupTips, bool bUseBackgroundTasks);
     virtual ~DialogPreferences ();
 
@@ -148,7 +153,7 @@ class ImageFile;
 class DialogGetMinMax : public wxDialog
 {
  public:
-    DialogGetMinMax (wxWindow* pParent, const char* const pszTitle, double dDefaultMin = 0., double dDefaultMax = 0.);
+    DialogGetMinMax (wxWindow* pParent, wxChar const* pszTitle, double dDefaultMin = 0., double dDefaultMax = 0.);
     virtual ~DialogGetMinMax ();
 
     double getMinimum ();
@@ -373,7 +378,7 @@ class DialogAutoScaleParameters : public wxDialog
 class DialogGetXYSize : public wxDialog
 {
  public:
-    DialogGetXYSize (wxWindow* pParent, const char* const pszTitle, int iDefaultXSize = 1, int iDefaultYSize = 1);
+    DialogGetXYSize (wxWindow* pParent, wxChar const * pwszTitle, int iDefaultXSize = 1, int iDefaultYSize = 1);
     virtual ~DialogGetXYSize ();
 
     unsigned int getXSize ();
@@ -391,7 +396,7 @@ class DialogGetXYSize : public wxDialog
 class DialogGetConvertPolarParameters : public wxDialog
 {
  public:
-   DialogGetConvertPolarParameters (wxWindow* pParent, const char* const pszTitle, int iDefaultXSize = 0,
+   DialogGetConvertPolarParameters (wxWindow* pParent, wxChar const * pwszTitle, int iDefaultXSize = 0,
      int iDefaultYSize = 0, int iDefaultInterpolationID = Projections::POLAR_INTERP_BILINEAR,
      int iDefaultZeropad = 3, int iHelpID = IDH_DLG_POLAR);
    virtual ~DialogGetConvertPolarParameters ();
