@@ -7,9 +7,7 @@
 **   Date Started:  Jan 2001
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -104,7 +102,7 @@ EZPlotControl::OnPaint (wxPaintEvent& event)
 
 
 wxEZPlotDialog::wxEZPlotDialog (wxWindow *parent, bool bCancelButton)
-: wxDialog((parent ? parent : theApp->getMainFrame()), -1, wxString("EZPlot"), wxDefaultPosition, wxDefaultSize, wxDIALOG_MODAL),
+: wxDialog((parent ? parent : theApp->getMainFrame()), -1, _T("EZPlot"), wxDefaultPosition, wxDefaultSize, wxDIALOG_MODAL),
   m_parentTop(0)
 {
   if (! parent)
@@ -119,10 +117,10 @@ wxEZPlotDialog::wxEZPlotDialog (wxWindow *parent, bool bCancelButton)
   pTopSizer->Add (m_pEZPlotCtrl = new EZPlotControl (this), 0, wxALIGN_CENTER | wxALL, 5);
 
   wxBoxSizer* pButtonSizer = new wxBoxSizer (wxHORIZONTAL);
-  wxButton* pButtonOk = new wxButton (this, wxID_OK, "Ok");
+  wxButton* pButtonOk = new wxButton (this, wxID_OK, _T("Ok"));
   pButtonSizer->Add (pButtonOk, 0, wxEXPAND | wxALL, 10);
   if (bCancelButton) {
-    wxButton* pButtonCancel = new wxButton (this, wxID_CANCEL, "Cancel");
+    wxButton* pButtonCancel = new wxButton (this, wxID_CANCEL, _T("Cancel"));
     pButtonSizer->Add (pButtonCancel, 0, wxEXPAND | wxALL, 10);
   }
   pTopSizer->Add (pButtonSizer, 0, wxALIGN_CENTER);
