@@ -7,9 +7,7 @@
  **   Date Started:  August 2000
  **
  **  This is part of the CTSim program
- **  Copyright (c) 1983-2001 Kevin Rosenberg
- **
- **  $Id$
+ **  Copyright (c) 1983-2009 Kevin Rosenberg
  **
  **  This program is free software; you can redistribute it and/or modify
  **  it under the terms of the GNU General Public License (version 2) as
@@ -58,8 +56,8 @@ BEGIN_EVENT_TABLE(ProjectionsDialog, wxDialog)
   IMPLEMENT_CLASS(ProjectionsDialog, wxDialog)
 
 
-  ProjectionsDialog::ProjectionsDialog (Scanner& rScanner, Projections& rProj, const Phantom& rPhantom, const int iTrace, wxWindow *parent)
-    : wxDialog(parent, -1, "Collect Projections", wxDefaultPosition), m_rScanner(rScanner), m_rProjections(rProj), m_rPhantom(rPhantom),
+ProjectionsDialog::ProjectionsDialog (Scanner& rScanner, Projections& rProj, const Phantom& rPhantom, const int iTrace, wxWindow *parent)
+: wxDialog(parent, -1, _T("Collect Projections"), wxDefaultPosition), m_rScanner(rScanner), m_rProjections(rProj), m_rPhantom(rPhantom),
       m_pSGPDriver(NULL), m_pSGP(NULL), m_iTrace(iTrace), m_pDC(NULL), m_btnAbort(0), m_btnPause(0), m_btnStep(0)
 {
   m_state = Continue;
@@ -79,7 +77,7 @@ BEGIN_EVENT_TABLE(ProjectionsDialog, wxDialog)
 
   m_btnAbort->SetConstraints(c);
 
-  m_btnPause = new wxButton (this, ID_BTN_PAUSE, wxString("Pause"));
+  m_btnPause = new wxButton (this, ID_BTN_PAUSE, _T("Pause"));
   wxLayoutConstraints* cPause = new wxLayoutConstraints;
   cPause->right.SameAs(this, wxRight, 3*LAYOUT_X_MARGIN + sizeBtn.x);
   cPause->bottom.SameAs(this, wxBottom, 2*LAYOUT_Y_MARGIN);
@@ -87,7 +85,7 @@ BEGIN_EVENT_TABLE(ProjectionsDialog, wxDialog)
   cPause->height.Absolute(sizeBtn.y);
   m_btnPause->SetConstraints(cPause);
 
-  m_btnStep = new wxButton (this, ID_BTN_STEP, wxString("Step"));
+  m_btnStep = new wxButton (this, ID_BTN_STEP, _T("Step"));
   wxLayoutConstraints* cStep = new wxLayoutConstraints;
   cStep->right.SameAs(this, wxRight, 5*LAYOUT_X_MARGIN + sizeBtn.x * 2);
   cStep->bottom.SameAs(this, wxBottom, 2*LAYOUT_Y_MARGIN);
@@ -127,9 +125,9 @@ BEGIN_EVENT_TABLE(ProjectionsDialog, wxDialog)
 
   wxYield();     // Update the display
 
-  m_pSGP->setTextPointSize(10);
+  m_pSGP->setTextPointSize(7);
 #ifdef __WXMAC__
-  MacUpdateImmediately();
+  //  MacUpdateImmediately();
 #endif
 }
 
@@ -187,7 +185,7 @@ ProjectionsDialog::projectView (int iViewNumber)
     showView (iViewNumber);
     wxYield();        // update the display
     if (m_iTrace >= Trace::TRACE_PLOT) {
-      ::wxUsleep(500);
+      ::wxMilliSleep(500);
     }
   } else {
     m_state = Finished;    // so that we return TRUE below and
@@ -195,7 +193,7 @@ ProjectionsDialog::projectView (int iViewNumber)
   }
 
 #ifdef __WXMAC__
-  MacUpdateImmediately();
+  //  MacUpdateImmediately();
 #endif
 
   return m_state != Cancelled;
@@ -232,12 +230,12 @@ ProjectionsDialog::OnPause (wxCommandEvent& event)
     m_pSGP->setDC (&m_memoryDC);
     showView (m_iLastView);
     m_state = Paused;
-    m_btnPause->SetLabel (wxString("Resume"));
+    m_btnPause->SetLabel (_T("Resume"));
     m_pSGP->setDC (m_pDC);
     m_memoryDC.SelectObject(wxNullBitmap);
   } else if (m_state == Paused) {
     m_state = Continue;
-    m_btnPause->SetLabel (wxString("Pause"));
+    m_btnPause->SetLabel (_T("Pause"));
   }
 }
 
@@ -252,7 +250,7 @@ ProjectionsDialog::OnStep (wxCommandEvent& event)
     showView (m_iLastView);
     // m_rScanner.collectProjections (m_rProjections, m_rPhantom, m_iLastView, 1, true, m_iTrace, m_pSGP);
     m_state = Paused;
-    m_btnPause->SetLabel (wxString("Resume"));
+    m_btnPause->SetLabel (_T("Resume"));
     m_pSGP->setDC (m_pDC);
     m_memoryDC.SelectObject(wxNullBitmap);
     Refresh();
@@ -298,4 +296,3 @@ ProjectionsDialog::~ProjectionsDialog()
   delete m_pSGPDriver;
   delete m_pDC;
 }
-
