@@ -7,9 +7,7 @@
 **   Date Started:  August 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -67,7 +65,7 @@ IMPLEMENT_CLASS(ReconstructDialog, wxDialog)
 
 ReconstructDialog::ReconstructDialog (Reconstructor& rReconstruct, const Projections& rProj,
                                       ImageFile& rIF, const int iTrace, wxWindow *parent)
-: wxDialog(parent, -1, "Reconstruction", wxDefaultPosition), m_rReconstructor(rReconstruct),
+: wxDialog(parent, -1, _T("Reconstruction"), wxDefaultPosition), m_rReconstructor(rReconstruct),
            m_rProjections(rProj), m_rImageFile(rIF), m_pSGPDriver(NULL), m_pSGP(NULL),
   m_iTrace(iTrace), m_pDC(NULL), m_btnAbort(0), m_btnPause(0), m_btnStep(0)
 {
@@ -77,7 +75,7 @@ ReconstructDialog::ReconstructDialog (Reconstructor& rReconstruct, const Project
     while ( m_parentTop && m_parentTop->GetParent() )
         m_parentTop = m_parentTop->GetParent();
 
-    m_btnAbort = new wxButton(this, wxID_CANCEL, _("Cancel"));
+    m_btnAbort = new wxButton(this, wxID_CANCEL, _T("Cancel"));
     wxLayoutConstraints* c = new wxLayoutConstraints;
     c->right.SameAs(this, wxRight, 2*LAYOUT_X_MARGIN);
     c->bottom.SameAs(this, wxBottom, 2*LAYOUT_Y_MARGIN);
@@ -88,7 +86,7 @@ ReconstructDialog::ReconstructDialog (Reconstructor& rReconstruct, const Project
 
     m_btnAbort->SetConstraints(c);
 
-    m_btnPause = new wxButton (this, ID_BTN_PAUSE, wxString("Pause"));
+    m_btnPause = new wxButton (this, ID_BTN_PAUSE, _T("Pause"));
     wxLayoutConstraints* cPause = new wxLayoutConstraints;
     cPause->right.SameAs(this, wxRight, 3*LAYOUT_X_MARGIN + sizeBtn.x);
     cPause->bottom.SameAs(this, wxBottom, 2*LAYOUT_Y_MARGIN);
@@ -96,7 +94,7 @@ ReconstructDialog::ReconstructDialog (Reconstructor& rReconstruct, const Project
     cPause->height.Absolute(sizeBtn.y);
     m_btnPause->SetConstraints(cPause);
 
-    m_btnStep = new wxButton (this, ID_BTN_STEP, wxString("Step"));
+    m_btnStep = new wxButton (this, ID_BTN_STEP, _T("Step"));
     wxLayoutConstraints* cStep = new wxLayoutConstraints;
     cStep->right.SameAs(this, wxRight, 5*LAYOUT_X_MARGIN + sizeBtn.x * 2);
     cStep->bottom.SameAs(this, wxBottom, 2*LAYOUT_Y_MARGIN);
@@ -223,7 +221,7 @@ ReconstructDialog::reconstructView (int iViewNumber, bool bBackproject)
                 showView (iViewNumber, bBackproject);
                 ::wxYield();        // update the display
                 if (m_iTrace >= Trace::TRACE_PLOT) {
-                        ::wxUsleep(250);
+                        ::wxMilliSleep(250);
                 }
         } else {
                 m_state = Finished;    // so that we return TRUE below and
@@ -267,12 +265,12 @@ ReconstructDialog::OnPause (wxCommandEvent& event)
                 m_memoryDC.SetFont (*wxSWISS_FONT);
                 showView (m_iLastView, false);
                 m_state = Paused;
-                m_btnPause->SetLabel (wxString("Resume"));
+                m_btnPause->SetLabel (_T("Resume"));
                 m_pSGP->setDC (m_pDC);
                 m_memoryDC.SelectObject(wxNullBitmap);
         } else if (m_state == Paused) {
                 m_state = Continue;
-                m_btnPause->SetLabel (wxString("Pause"));
+                m_btnPause->SetLabel (_T("Pause"));
         }
 }
 
@@ -288,7 +286,7 @@ ReconstructDialog::OnStep (wxCommandEvent& event)
                 m_memoryDC.SetFont (*wxSWISS_FONT);
                 showView (m_iLastView, false);
                 m_state = Paused;
-                m_btnPause->SetLabel (wxString("Resume"));
+                m_btnPause->SetLabel (_T("Resume"));
                 m_pSGP->setDC (m_pDC);
                 m_memoryDC.SelectObject(wxNullBitmap);
                 Refresh();
