@@ -3,13 +3,11 @@
 **
 **   Name:          phm2helix.cpp
 **   Purpose:       Take projections of a phantom object
-**   Programmer:    Ian Kay
+**   Programmers:   Ian Kay and Kevin Rosenberg
 **   Date Started:  Aug 2001
 **
 **  This is part of the CTSim program
-**  Copyright (C) 1983-2000 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (C) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -303,7 +301,9 @@ phm2helix_main (int argc, char* const argv[])
                         std::cout  <<  opt_PhmProg  <<  " " << iView << " " <<  opt_nview << " " << opt_PhmFileName  << std::endl;
            //extcommand <<  opt_PhmProg  <<  " " << iView << " " <<  opt_nview << " " << opt_PhmFileName ;
 
-                        sprintf(extcommand, "%s %d %d %s",      opt_PhmProg.c_str(), iView, opt_nview, opt_PhmFileName.c_str() );
+                sprintf(extcommand, "%s %d %d %s",      
+                        opt_PhmProg.c_str(), iView, opt_nview, 
+                        opt_PhmFileName.c_str() );
                 stat = system( extcommand );
 
                 if (stat != 0 )
@@ -318,18 +318,18 @@ phm2helix_main (int argc, char* const argv[])
 
 
           pjGlobal.setCalcTime (timerProgram.timerEnd());
-                pjGlobal.setRemark (opt_desc);
-                pjGlobal.write (opt_outfile);
-                if (opt_verbose) {
-                  phm.print (std::cout);
-                  std::cout << std::endl;
-                std::ostringstream os;
-                pjGlobal.printScanInfo (os);
-                std::cout << os.str() << std::endl;
-                std::cout << "  Remark: " << pjGlobal.remark() << std::endl;
-                std::cout << "Run time: " << pjGlobal.calcTime() << " seconds\n";
+          pjGlobal.setRemark (opt_desc);
+          pjGlobal.write (opt_outfile);
+          if (opt_verbose) {
+            phm.print (std::cout);
+            std::cout << std::endl;
+            std::ostringstream os;
+            pjGlobal.printScanInfo (os);
+            std::cout << os.str() << std::endl;
+            std::cout << "  Remark: " << pjGlobal.remark() << std::endl;
+            std::cout << "Run time: " << pjGlobal.calcTime() << " seconds\n";
           }
-
+          
           return (0);
 }
 
